{% extends "blocks/unical_menu_grey_box_generic.html" %}

{% load i18n %}
{% load static %}

{% block icon %}
<div class="col-2">
    <b>
        <svg class="icon" aria-labelledby="info_menu">
            <title id="info_menu">{% trans "Informations" %}</title>
            <use xlink:href="{% static 'svg/sprites.svg' %}#it-arrow-right-circle"></use>
        </svg>
    </b>
</div>
{% endblock %}

