{% extends "department.html" %}

{% load i18n %}
{% load static %}

<!-- load custom template tags -->
{% load unicms_carousels %}
{% load unicms_contexts %}
{% load unicms_menus %}
{% load unicms_templates %}
{% load unicms_pages %}
{% load unicms_publications %}
{% load unicms_template_unical %}

<!-- Logo in Header -->
{% block header_center_logo_side %}
<image src="{% unicms_template_unical_static_path 'images/logos/diam.svg' %}" class="h-100" />
{% endblock header_center_logo_side %}

{% block header_slim_mobile_org_name_side %}
<image src="{% unicms_template_unical_static_path 'images/logos/diam.svg' %}" class="mw-100" />
{% endblock header_slim_mobile_org_name_side %}

{% block department_contacts %}
<div class="col-12 col-lg-3">
    <div class="mb-3">
        <image src="{% unicms_template_unical_static_path 'images/logos/diam.svg' %}"
               class="w-100 h-100"
               alt="{% trans 'Department of Environmental Engineering' %}"/>
    </div>
    <p class="mb-4">
        Via P. Bucci - Cubo 44A
        <br>
        87036 Arcavacata di Rende (CS)
        <br>
        <a class="text-white" href="mailto:dipartimento.diam@pec.unical.it" title="dipartimento.diam@pec.unical.it">dipartimento.diam@pec.unical.it</a>
    </p>
</div>
{% endblock department_contacts %}
