/**
 * Università della Calabria
 * Portale Style SCSS
 */

/**
 * Università della Calabria COLORS
 */

@import "unical-style";

$cyan: #176fc1;
$grey: #d3d2cf;
$light_grey: #e3e9ec;

$darker_bordeaux: #6f0b0a;
$lighter_bordeaux: #e03231;

@font-face {
  font-family: TitilliumWeb-Black;
  src: url(../fonts/TitilliumWeb-Black.ttf);
  font-display: swap;
}

a {
    text-decoration: none;
    color: #B01717;
    text-decoration: underline;
}

a:hover, a:active {
    color: #6f0b0a;
    text-decoration: none;
}

/** only visited **/
a.no-color,
ol.breadcrumb a  {
    color: $dark_grey_unical;
    text-decoration: none;
}

a.no-color:hover,
a.no-color:active,
ol.breadcrumb a:hover,
ol.breadcrumb a:active  {
    text-decoration: underline;
}
/** end only visited **/


.super-bold {
    font-family: TitilliumWeb-Black;
}

.lighter {
    font-weight: lighter;
}

.background-yellow {
    background: #ffed00;
}

.background-white {
    background: $white;
}

.background-light-grey {
    background: $light_grey;
    color: $dark_grey_unical;
}

.icon-light {
    fill: #fff !important;
}

.bigger-font {
    font-size: 1.5rem;
}

.negative-mt-5 {
    margin-top: -48px;
}

.dark-grey-background {
    background: $grey;
}

.it-header-center-wrapper {
    background: $bordeaux_unical;
}

.it-header-center-wrapper .it-header-center-content-wrapper .it-right-zone {
    color: #fff;
}

input.top-input {
    background: none;
    border: 1px solid #fff;
    height: 1.7rem;
    width: 100%;
    color: $white;
}

.it-hero-wrapper .it-hero-text-wrapper h1 {
    background: #fff;
    color: $dark_grey_unical;
    padding: 1rem;
    font-family: TitilliumWeb-Black;
}

.it-hero-wrapper.it-overlay.it-dark .img-responsive-wrapper:after {
    background: none;
}

.section-title-label {
    background: #fff;
}

.card.card-bg {
    margin-left: 0;
    margin-right: 0;
}


.card .card-body .category-top {
    text-transform: none;
}

.card .etichetta {
    font-size: 1rem;
    text-transform: lowercase;
    margin-bottom: 15px;
    color: $cyan;
    display: block;
}
.card-title {
    font-weight: bold;
}
.card .card-title {
    line-height: 1;
}
.card .card-body .card-text {
    font-family: Titillium Web;
    font-size: 16px;
}

.btn-grey-presta {
    background: $grey;
}
.btn-grey-presta:hover {
    color: $white;
    background: $dark_grey_unical;
}
.bg-dark .btn-secondary {
    background: $bordeaux_unical;
}
.bg-dark .btn-secondary:hover {
    background: $dark_grey_unical;
}

.it-right-zone .nav-link {
    color: $white;
}

@media (max-width: 991px) {
    .custom-navbar-toggler svg {
        fill: $white;
    }
}

.nav-mobile {
    width: 100%;
}

.it-header-slim-wrapper {
    background: $dark_grey_unical;
    border-bottom: 1px solid #fff;
}

.it-header-slim-wrapper .container {
    padding-left: 0;
    padding-right: 0;
}

.badge-grey-unical {
    background: $light_grey;
    color: $dark_grey_unical;
    font-weight: 500;
}
.badge-left-text-unical {
    text-align: left;
    white-space: inherit;
}
a .badge-grey-unical:hover,
a .badge-grey-unical.selected {
    background: $dark_grey_unical;
        color: $light_grey;
        text-decoration: none;
}

.square-corners {
    border-radius: 0;
}

.publication-hero {
    min-height: 300px;
}

.breadcrumb-container {
    padding-top: 15px;
    padding-bottom: 15px;
    border-top: 2px solid $bordeaux_unical;
    border-bottom: 2px solid $bordeaux_unical;
    font-size: 0.78rem;
}
.breadcrumb-container .breadcrumb {
    margin-bottom: 0;
}


.it-header-wrapper .it-nav-wrapper .it-header-navbar-wrapper {
    margin-top: -45px;
}
/**
 * Medium with
 */
@media (min-width: 992px) {
    .it-header-wrapper .it-nav-wrapper .it-header-navbar-wrapper {
        padding-top: 1.7rem;
        margin-top: 0;
    }
    .it-header-wrapper .it-nav-wrapper .it-header-navbar-wrapper nav {
        padding-left: 0;
        padding-right: 0;
    }
    .it-header-center-wrapper .it-header-center-content-wrapper {
        padding-left: 0;
        padding-right: 0;
    }
    .navbar .navbar-collapsable .navbar-nav li.nav-item {
        font-size: 1.2rem;
    }
    .it-header-navbar-wrapper {
        background: $white;
    }
}

}


/**
 * De Marco
 */
.menu-wrapper {
    z-index: 1 !important;
    }

.owl-carousel {
    z-index: 0;
}

.owl-nav {
    display: none;
}

.owl-carousel-cards .owl-stage,
.custom-unical .owl-stage{
    display: -webkit-flex;
    display: -ms-flexbox;
    display: flex;

    -webkit-flex-wrap: wrap;
    -ms-flex-wrap: wrap;
    flex-wrap: wrap;
}

.owl-carousel-cards .owl-item,
.custom-unical .owl-item{
    display: -webkit-flex;
    display: -ms-flexbox;
    display: grid;
    height: auto !important;
}

.custom-unical .card-wrapper {
    padding-bottom: 16px;
}

.it-carousel-wrapper.custom-unical .owl-carousel .owl-dots {
    display: none;
}

.navbar .navbar-collapsable .navbar-nav li a.nav-link {
    color: #000;
    border-bottom: none !important;
}

.it-carousel-wrapper .owl-stage-outer {
    padding-top: 0px;
    padding-bottom: 0;
}


.it-hero-wrapper {
    background-color: #fff !important;
}


/**
 * Main Menu
 */
.dropdown-menu {
    padding: 16px 2px !important;
}


.navbar .dropdown-menu:before {
    display: none;
}

.bordeaux-unical-bg {
    background: $bordeaux_unical;
}

.bordeaux-unical-color {
    color: $bordeaux_unical;
}

.white-unical-color {
    color: $white;
}

.link-list-wrapper ul li a {
    line-height: inherit;
}


// Main menu dropdown hack!

@media all and (min-width: 992px) {
	.navbar .nav-item .dropdown-menu{ display: none; }
	.navbar .nav-item:hover .nav-link{ text-decoration: underline}
	.navbar .nav-item:hover .dropdown-menu{ display: block; }
	.navbar .nav-item .dropdown-menu{ margin-top:0; }
}

@media all and (max-width: 991px) {
    .navbar .nav-item a.nav-link {
        float: left;
    }
    .navbar .nav-item span.megamenu-dropdown-arrow {
        float: right;
        margin: 10px;
    }
    .navbar .nav-item .dropdown-menu {
        float: left;
    }
}

.accordion.accordion-left-icon .accordion-header .accordion-button:before {
    flex: none;
}

.accordion-header [data-bs-toggle=collapse][aria-expanded=false],
.accordion-header [data-bs-toggle=collapse]:before {
    color: $dark_grey_unical;
}

.accordion-left-icon .collapse-header [data-bs-toggle=collapse][aria-expanded=false]:before {
    content: url("data:image/svg+xml;base64,PHN2ZyB2aWV3Qm94PSIwIDAgMjQgMjQiIGlkPSJpdC1wbHVzLWNpcmNsZSIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KPGcgaWQ9IkxpdmVsbG9fMTMiIGRhdGEtbmFtZT0iTGl2ZWxsbyAxMyI+CiAgICA8cGF0aCAgZmlsbD0iIzM4MzgzOCIgZD0iTTEyLjQgMTEuNWg0LjV2MWgtNC41VjE3aC0xdi00LjVINi45di0xaDQuNVY3aDF6bTkuNi41QTEwIDEwIDAgMTExMiAyYTEwIDEwIDAgMDExMCAxMHptLTEgMGE5IDkgMCAxMC05IDkgOSA5IDAgMDA5LTl6Ii8+PC9nPjwvc3ZnPg==") !important;
    margin-bottom: 0;
}
.accordion-left-icon .collapse-header [data-bs-toggle=collapse][aria-expanded=true]:before {
    content: url("data:image/svg+xml;base64,PHN2ZyB2aWV3Qm94PSIwIDAgMjQgMjQiIGlkPSJpdC1wbHVzLWNpcmNsZSIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KPGcgaWQ9IkxpdmVsbG9fMTMiIGRhdGEtbmFtZT0iTGl2ZWxsbyAxMyI+CiAgICA8cGF0aCAgZmlsbD0iIzM4MzgzOCIgZD0iTTYuOSAxMS41aDEwdjFoLTEwek0yMiAxMkExMCAxMCAwIDExMTIgMmExMCAxMCAwIDAxMTAgMTB6bS0xIDBhOSA5IDAgMTAtOSA5IDkgOSAwIDAwOS05eiIvPjwvZz48L3N2Zz4=") !important;
    margin-bottom: 0;
}

.accordion-header button[aria-expanded="true"]::before {
    height: 1.5rem !important;
    width: 1.5rem !important;
}

.accordion-header{
    border-color: #e3e4e6 !important;
}

.nav-tabs .nav-link,
.nav-tabs .nav-link:hover {
    color: $light_grey_unical;
}
.nav-tabs .nav-item.show .nav-link, .nav-tabs .nav-link.active {
    border-bottom-color: $bordeaux_unical;
    color: $dark_grey_unical;
}

.link-list-wrapper ul li a span,
.link-list-wrapper ul li a:hover:not(.disabled) span {
    color: $dark_grey_unical;
}

.department_logo_lg {
    height: 63px
}

select.form-control {
    border-width: 1px;
    appearance: auto;
}

.card .card-body a h5.card-title {
    color: $dark_grey_unical;
}


.it-header-center-wrapper {
    ::-webkit-input-placeholder { /* WebKit, Blink, Edge */
        color: inherit;
    }
    :-moz-placeholder { /* Mozilla Firefox 4 to 18 */
       color: inherit;
       opacity: 1;
    }
    ::-moz-placeholder { /* Mozilla Firefox 19+ */
       color: inherit;
       opacity: 1;
    }
    :-ms-input-placeholder { /* Internet Explorer 10-11 */
       color: inherit;
    }
    ::-ms-input-placeholder { /* Microsoft Edge */
       color: inherit;
    }

    ::placeholder { /* Most modern browsers support this now. */
       color: inherit;
    }
}


.progress-spinner.progress-spinner-double .progress-spinner-inner:after {
    border: 4px solid $bordeaux_unical;
    border-right: 4px solid transparent;
    border-bottom: 4px solid transparent;
}

figure.table tr:nth-of-type(2n) {
    background-color: #f6f7f9;
}

.col img {
    max-width: 100%;
}

.unical-alert ul {
    margin-bottom: 0;
}

.progress {
    background-color: $light_grey;
}
.progress-bar {
    background-color: $bordeaux_unical;
}

@media all and (max-width: 768px) {
    .full-width-mobile {
        width: 100%;
    }
}

.card-columns-2 {
    column-count: 2;
}

@media all and (max-width: 992px) {
	.card-columns-2 {
        column-count: 1;
    }
}

/**
 * fix publication tables images size
 */
figure.table table td figure.image {
    text-align: center;
}
figure.table table td figure.image img {
    width: 80px;
    max-width: 80px;
}

.it-footer {
    border-top: 1px solid rgba(0,0,0,.1)
}

.it-footer-small-prints {
    border-top: 1px solid #fff;
}

/**
 * UniCal Hero slider
 */
@media (max-width: 991px) {
    .it-hero-text-wrapper.unical-hero-text-wrapper {
        padding: 26px;
    }
}
@media (min-width: 992px) {
    .it-hero-text-wrapper.unical-hero-text-wrapper {
        padding: 120px 26px 168px;
    }
}

.it-hero-wrapper .it-hero-text-wrapper h5.unical-hero-preheading {
    padding: 20px;
    background: $bordeaux_unical;
    position: inherit;
    text-transform: inherit;
    color: #fff;
    width: fit-content;
    font-weight: bold;
    margin-bottom: 24px;
}

.it-hero-wrapper .it-hero-text-wrapper h6.unical-hero-preheading {
    padding: 10px 20px;
    background: $bordeaux_unical;
    position: inherit;
    text-transform: inherit;
    color: #fff;
    width: fit-content;
    font-weight: bold;
    margin-bottom: 12px;
}

.it-hero-wrapper .it-hero-text-wrapper h1.unical-hero-heading,
.it-hero-wrapper .it-hero-text-wrapper h2.unical-hero-heading,
.it-hero-wrapper .it-hero-text-wrapper h3.unical-hero-heading,
.it-hero-wrapper .it-hero-text-wrapper h4.unical-hero-heading {
    background: #fff;
    color: $bordeaux_unical;
    padding: 1rem;
    font-family: Lora;
    font-style: italic;
    width: fit-content;
}
.it-hero-wrapper .it-hero-text-wrapper h1.unical-hero-description,
.it-hero-wrapper .it-hero-text-wrapper h2.unical-hero-description,
.it-hero-wrapper .it-hero-text-wrapper h3.unical-hero-description,
.it-hero-wrapper .it-hero-text-wrapper h4.unical-hero-description {
    background: $bordeaux_unical;
    color: #fff;
    padding: 1rem;
    font-family: Lora;
    font-style: italic;
    width: fit-content;
}

.it-hero-wrapper.unical-hero-wrapper-slim {
    min-height: 300px;
}
@media (min-width: 992px) {
    .it-hero-wrapper.unical-hero-wrapper-slim .it-hero-text-wrapper.unical-hero-text-wrapper {
        padding: 20px 26px;
    }
}

.it-footer-main {
    font-size: 15px;
}

.it-footer-main h4 a {
    border-bottom: 1px solid $bordeaux_unical;
}

@media (max-width: 991px) {
    .it-footer-main .link-list-wrapper ul li a {
        padding: 24px 0;
    }
}

/** Owl CLS fix */
.owl-carousel {
    display: block;
}

.owl-carousel .slide-owl-wrap:not(:first-child) {
    display: none;
}

.owl-carousel img {
    width: 100%;
}



@media (min-width: 992px) {
    .ps-lg-2, .px-lg-2 {
        padding-left: 8px !important;
    }
}

@media (min-width: 992px) {
    .pe-lg-1, .px-lg-1 {
        padding-right: 4px !important;
    }
}

input.top-input::placeholder {
    color: #fff;
}

/** Negative margin fix */
.ms-n1 {
    margin-left: -4px;
}

.me-n1 {
    margin-right: -4px;
}

.mx-n1 {
    margin-left: -4px;
    margin-right: -4px;
}

.ms-n2 {
    margin-left: -8px;
}

.me-n2 {
    margin-right: -8px;
}

.mx-n2 {
    margin-left: -8px;
    margin-right: -8px;
}

.ms-n3 {
    margin-left: -16px;
}

.me-n3 {
    margin-right: -16px;
}

.mx-n3 {
    margin-left: -16px;
    margin-right: -16px;
}

.ms-n4 {
    margin-left: -24px;
}

.me-n4 {
    margin-right: -24px;
}

.mx-n4 {
    margin-left: -24px;
    margin-right: -24px;
}

.ms-n5 {
    margin-left: -48px;
}

.me-n5 {
    margin-right: -48px;
}

.mx-n5 {
    margin-left: -48px;
    margin-right: -48px;
}


/** Gutter to 12px */
.row {
    --bs-gutter-x: 12px;
}

.input-group-append .btn,
.input-group-prepend .btn {
    z-index: inherit;
}
