{% load i18n %}
{% load static %}

{% load unicms_contexts %}
{% load unicms_menus %}


{% if title %}
<div>
    <h1 class="lighter">
        {% if link %}
        <a href="{{ link }}" class="no-color">
        {% endif %}
            {{ title }}
        {% if link %}
        </a>
        {% endif %}
    </h1>
    <hr class="my-4 bordeaux-unical-bg">
</div>
{% endif %}

{% for item in items %}

    {% call obj=item method='link' request=request as link %}

    <a class="no-color" href="{% if item.link %}{{ link }}{% else %}#{% endif %}">
        <span class="{% if item == current %}selected{% endif %} badge badge-grey-unical badge-left-text-unical square-corners my-1 me-3 ms-0 pe-5 p-2 mw-100">
                <h5>
                    {% if item == current %}<b>{% endif %}
                    {{ item.name }}
                    {% if item == current %}</b>{% endif %}
                </h5>
        </span>
    </a>
{% endfor %}

<hr class="my-4 bordeaux-unical-bg">
