{% extends "bases/unicms_unical.html" %}

{% load i18n %}
{% load static %}

<!-- load custom template tags -->
{% load unicms_carousels %}
{% load unicms_contexts %}
{% load unicms_menus %}
{% load unicms_templates %}
{% load unicms_pages %}
{% load unicms_publications %}
{% load unicms_template_unical %}

{% block header_slim_wrapper %}
{% settings_value "MAIN_DOMAIN" as cms_main_domain %}
<div class="it-header-slim-wrapper">
    <div class="container">
        <div class="row">
            <div class="col-12">
                <div class="it-header-slim-wrapper-content">
                    <a target="_blank" href="//{{ cms_main_domain }}" title="UniCal.it" alt="UniCal.it">
                        <b>UniCal.it</b>
                    </a>
                    {% if request.user.is_staff %}
                    {% include "components/italia_editorialboard_frontend_menu.html" %}
                    {% endif %}
                </div>
            </div>
        </div>
    </div>
</div>
<a href="/" aria-label="{% trans 'University of Calabria' %}">
    <div class="it-header-center-wrapper d-lg-none h-auto pt-4">
        {% block unical_mobile_logo %}
            {% block header_slim_mobile_org_name_side %}
                <image src="{% unicms_template_unical_static_path 'images/unical_logo_bullet_white.svg' %}" class="mw-100"/>
            {% endblock header_slim_mobile_org_name_side %}
        {% endblock unical_mobile_logo %}
    </div>
</a>
{% endblock header_slim_wrapper %}

{% block header_center_logo %}
    <div class="d-none d-lg-flex col-lg-12 px-0 department_logo_lg">
        {% block header_center_logo_side %}
        <image src="{% static 'unicms_template_unical_static_path/unical_logo_bullet_white.svg' %}" class="h-100" />
        {% endblock header_center_logo_side %}
    </div>
{% endblock header_center_logo %}

{% block header_slim_right_zone %}
{% if request.user.is_staff %}
{% include "components/italia_editorialboard_frontend_menu.html" %}
{% endif %}
{% endblock header_slim_right_zone %}

{% block addressbook_link %}{% settings_value "DEPARTMENT_ADDRESSBOOK_LINK" as department_addressbook_link %}{{ department_addressbook_link }}{% endblock addressbook_link %}

{% block unical_header_languages %}
<div class="dark-grey-background py-2">
    <div class="container text-center text-lg-end">
        <div class="row">
            <div class="col">
                {% language_menu as language_urls %}
                {% for cod,params in language_urls.items %}
                    {% load_lang_flag cod as flag_path %}
                    <a href="{{ params.1 }}" style="cursor: pointer;" title="{{ params.0 }}">
                        <img src="{{ flag_path }}" alt="{{ params.0 }}" style="width: 27px; height: 27px;" class="me-2"/>
                    </a>
                {% endfor %}
            </div>
        </div>
    </div>
</div>
{% endblock unical_header_languages %}

<!-- Footer middle section with menu blocks -->
{% block footer_menu_section %}
{% endblock footer_menu_section %}

{% block footer_contacts_section %}
{% endblock footer_contacts_section %}

{% block footer_bottom %}
<div class="it-footer-main clearfix py-4 border-white border-top" style="background: #b71918;">
    <div class="container">
        <section>
            {% block footer_bottom_content %}
            <div class="row">
                <div class="col-12 col-lg-9">
                    <div class="row">
                        {% block footer_bottom_1 %}
                        <div class="col-lg-4 col-sm-6">
                            <div class="link-list-wrapper">
                                <ul class="footer-list link-list clearfix">
                                    <li><a class="list-item" href="/dipartimento/presentazione/" title="{% trans 'Presentation' %}">{% trans 'Presentation' %}</a></li>
                                    <li><a class="list-item" href="/dipartimento/presentazione/persone/" title="{% trans 'People' %}">{% trans 'People' %}</a></li>
                                    <li><a class="list-item" href="/dipartimento/organizzazione/servizi-personale/" title="{% trans 'Staff services' %}">{% trans 'Staff services' %}</a></li>
                                    <li><a class="list-item" href="/dipartimento/organizzazione/documenti-bandi-e-concorsi/" title="{% trans 'Documents, announcements and competitions' %}">{% trans 'Documents, announcements and competitions' %}</a></li>
                                </ul>
                            </div>
                        </div>
                        {% endblock footer_bottom_1 %}

                        {% block footer_bottom_2 %}
                        <div class="col-lg-4 col-sm-6">
                            <div class="link-list-wrapper">
                                <ul class="footer-list link-list clearfix">
                                    <li><a class="list-item" href="https://www.unical.it/front-office" title="{% trans 'Online front-office' %}">{% trans 'Online front-office' %}</a></li>
                                    <li><a class="list-item" href="https://ticket.unical.it" target="_blank" rel="noopener noreferrer" title="{% trans 'Online ticket' %}">{% trans 'Online ticket' %}</a></li>
                                    <li><a class="list-item" href="https://smartcampus.unical.it/" target="_blank" rel="noopener noreferrer" title="{% trans 'Smart Campus' %}">{% trans 'Smart Campus' %}</a></li>
                                    <li><a class="list-item" href="https://soscr.unical.it/Default.aspx?tabid=212" target="_blank" rel="noopener noreferrer" title="{% trans 'Unical Life' %}">{% trans 'Unical Life' %}</a></li>
                                </ul>
                            </div>
                        </div>
                        {% endblock footer_bottom_2 %}

                        {% block footer_bottom_3 %}
                        <div class="col-lg-4 col-sm-6">
                            <div class="link-list-wrapper">
                                <ul class="footer-list link-list clearfix">
                                    <li><a class="list-item" href="https://www.unical.it/organizzazione/chi-siamo/portale-trasparenza/" title="{% trans 'Transparent administration' %}">{% trans 'Transparent administration' %}</a></li>
                                    <li><a class="list-item" href="https://www.unical.it/accessibilita/" title="{% trans 'Accessibility and performance' %}">{% trans 'Accessibility and performance' %}</a></li>
                                    <li><a class="list-item" href="https://www.unical.it/privacy/" title="{% trans 'Data protection / GDPR' %}">{% trans 'Data protection / GDPR' %}</a></li>
                                    <li><a class="list-item" href="https://www.unical.it/cookie/" title="{% trans 'Cookies and consent methods' %}">{% trans 'Cookies and consent methods' %}</a></li>
                                    <li><a class="list-item" href="https://www.unical.it/note-legali/" title="{% trans 'Legal notes' %}">{% trans 'Legal notes' %}</a></li>
                                    <li><a class="list-item" href="/sitemap/" title="{% trans 'Sitemap' %}">{% trans 'Sitemap' %}</a></li>
                                </ul>
                            </div>
                        </div>
                        {% endblock footer_bottom_3 %}
                    </div>
                </div>

                {% block department_contacts %}
                <div class="col-12 col-lg-3">
                    <div class="mb-3">
                        <image src="{% unicms_template_unical_static_path 'images/logo_unical_white.svg' %}"
                               class="w-100 h-100"
                               alt="{% trans 'University of Calabria' %}"/>
                    </div>
                    <p class="mb-4">
                        Via Pietro Bucci
                        <br>
                        87036 Rende CS
                        <br>
                        <a class="text-white" href="/portale/pec" title="{% trans 'Certified email' %}">{% trans 'Certified email' %}</a>
                        <br>
                        C.F. 80003950781 / P.I. 00419160783
                    </p>
                </div>
                {% endblock department_contacts %}
            </div>
            {% endblock footer_bottom_content %}
        </section>
    </div>
</div>
{% endblock footer_bottom %}
