{% load i18n %}
{% load static %}
{% load unicms_template_unical %}

<div class="it-hero-wrapper it-dark it-overlay publication-hero mb-4 ">
  <!-- - img-->
  <div class="img-responsive-wrapper">
    <div class="img-responsive">
        <div class="img-wrapper w-50 center-block">
            <img src="{% unicms_template_unical_static_path 'images/loading.gif' %}"/>
        </div>
    </div>
  </div>
  <!-- - texts-->
  <div class="container">
    <div class="row">
        <div class="col-12">
          <div class="it-hero-text-wrapper bg-dark">
              <span class="it-category">
                {% trans "please wait" %}
              </span>
              <h1 class="no_toc"><h2>{% trans "Loading" %} ...</h2></h1>
          </div>
        </div>
    </div>
  </div>
</div>
